cairnloop
v0.5.1
Search documentation of cairnloop
Default
Default
In-browser search
Settings
Cairnloop.
Ingress.
EmailParser
(cairnloop v0.5.1)
Summary
Functions
parse(email_body)
Parses an email body to strictly isolate new reply text from quoted history.
Functions
parse(email_body)
Parses an email body to strictly isolate new reply text from quoted history.